Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authordave@33eels.com <dave@33eels.com@4eb1ac78-321c-0410-a911-ec516a8615a5>2009-03-06 18:21:07 (GMT)
committer dave@33eels.com <dave@33eels.com@4eb1ac78-321c-0410-a911-ec516a8615a5>2009-03-06 18:21:07 (GMT)
commit92e7daadd85ae7e6ff88eb229827d6cf1fab3c0f (patch)
treeae1489d0e1c44747708f82d354ea5e0774f98c2b
parent40f3a585698b527181ab2abf366096b7d14ef387 (diff)
Restored some level of workingness since previous breakage.
git-svn-id: http://svn.mozilla.org/addons/trunk@22943 4eb1ac78-321c-0410-a911-ec516a8615a5
-rw-r--r--bandwagon/components/bandwagon-service.js11
-rw-r--r--bandwagon/content/scripts/bandwagon.js4
-rw-r--r--bandwagon/content/scripts/factory/collectionFactory.js4
-rw-r--r--bandwagon/content/scripts/logger.js4
-rw-r--r--bandwagon/content/scripts/model/addon.js4
-rw-r--r--bandwagon/content/scripts/model/collection.js4
-rw-r--r--bandwagon/content/scripts/model/serviceDocument.js4
-rw-r--r--bandwagon/content/ui/bindings/bandwagon.css12
-rw-r--r--bandwagon/content/ui/bindings/bandwagon.xml172
-rw-r--r--bandwagon/content/ui/collectionsPaneController.js4
-rw-r--r--bandwagon/content/ui/dialog.js4
-rw-r--r--bandwagon/content/ui/overlays/browserOverlayController.js52
-rw-r--r--bandwagon/content/ui/overlays/extensionsOverlay.xul48
-rw-r--r--bandwagon/content/ui/overlays/extensionsOverlayController.js72
-rw-r--r--bandwagon/locale/en-US/extensionsOverlay.dtd4
-rw-r--r--bandwagon/skin/extensionsOverlay.css56
-rw-r--r--bandwagon/skin/global.css2
-rw-r--r--bandwagon/skin/settings.css8
18 files changed, 235 insertions, 234 deletions
diff --git a/bandwagon/components/bandwagon-service.js b/bandwagon/components/bandwagon-service.js
index 5978383..8d42071 100644
--- a/bandwagon/components/bandwagon-service.js
+++ b/bandwagon/components/bandwagon-service.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -429,12 +429,13 @@ BandwagonService.prototype = {
firstrun: function()
{
- Bandwagon.Logger.info("This is bandwagon's firstrun");
+ Bandwagon.Logger.info("This is bandwagon's firstrun. Welcome!");
// set up and save default collections
- this._addDefaultCollection(Bandwagon.DEFAULT_COLLECTION1_URL, Bandwagon.DEFAULT_COLLECTION1_NAME);
- this._addDefaultCollection("http://www.33eels.com/clients/briks/bandwagon/testcollection.xml", "test collection");
+ // FIXME temporarily disabling this
+ //this._addDefaultCollection(Bandwagon.DEFAULT_COLLECTION1_URL, Bandwagon.DEFAULT_COLLECTION1_NAME);
+ //this._addDefaultCollection("http://www.33eels.com/clients/briks/bandwagon/testcollection.xml", "test collection");
// check for cookie to see if we have to add a collection like that
diff --git a/bandwagon/content/scripts/bandwagon.js b/bandwagon/content/scripts/bandwagon.js
index 1532c58..154c6ea 100644
--- a/bandwagon/content/scripts/bandwagon.js
+++ b/bandwagon/content/scripts/bandwagon.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/scripts/factory/collectionFactory.js b/bandwagon/content/scripts/factory/collectionFactory.js
index 0b2c4e7..6cdd585 100644
--- a/bandwagon/content/scripts/factory/collectionFactory.js
+++ b/bandwagon/content/scripts/factory/collectionFactory.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/scripts/logger.js b/bandwagon/content/scripts/logger.js
index ce8d42c..b4393df 100644
--- a/bandwagon/content/scripts/logger.js
+++ b/bandwagon/content/scripts/logger.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/scripts/model/addon.js b/bandwagon/content/scripts/model/addon.js
index aed41b1..58e74fc 100644
--- a/bandwagon/content/scripts/model/addon.js
+++ b/bandwagon/content/scripts/model/addon.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/scripts/model/collection.js b/bandwagon/content/scripts/model/collection.js
index 18a0535..67fb958 100644
--- a/bandwagon/content/scripts/model/collection.js
+++ b/bandwagon/content/scripts/model/collection.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/scripts/model/serviceDocument.js b/bandwagon/content/scripts/model/serviceDocument.js
index e405f6d..67e87eb 100644
--- a/bandwagon/content/scripts/model/serviceDocument.js
+++ b/bandwagon/content/scripts/model/serviceDocument.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/ui/bindings/bandwagon.css b/bandwagon/content/ui/bindings/bandwagon.css
index 1d012cc..7bb9f18 100644
--- a/bandwagon/content/ui/bindings/bandwagon.css
+++ b/bandwagon/content/ui/bindings/bandwagon.css
@@ -1,13 +1,13 @@
-bandwagonFeedItem {
- -moz-binding: url("chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-feeditem");
+bandwagonAddon {
+ -moz-binding: url("chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-addon");
}
-bandwagonFeedItemExpanded {
- -moz-binding: url("chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-feeditem-expanded");
+bandwagonAddonExpanded {
+ -moz-binding: url("chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-addon-expanded");
}
-bandwagonFeed {
- -moz-binding: url("chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-feed");
+bandwagonCollection {
+ -moz-binding: url("chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-collection");
}
bandwagonPublishButton {
diff --git a/bandwagon/content/ui/bindings/bandwagon.xml b/bandwagon/content/ui/bindings/bandwagon.xml
index 600d9f3..027170c 100644
--- a/bandwagon/content/ui/bindings/bandwagon.xml
+++ b/bandwagon/content/ui/bindings/bandwagon.xml
@@ -44,7 +44,7 @@
xmlns:xbl="http://www.mozilla.org/xbl"
xmlns:html="http://www.w3.org/1999/xhtml">
- <binding id="bandwagon-feed" extends="chrome://global/content/bindings/richlistbox.xml#richlistitem">
+ <binding id="bandwagon-collection" extends="chrome://global/content/bindings/richlistbox.xml#richlistitem">
<resources>
<stylesheet src="chrome://bandwagon/skin/extensionsOverlay.css"/>
@@ -59,13 +59,13 @@
</content>
<implementation>
- <field name="feed"/>
+ <field name="collection"/>
<field name="controller"/>
<constructor>
<![CDATA[
- if (this.feed)
- this.setFeed(this.feed);
+ if (this.collection)
+ this.setCollection(this.collection);
setTimeout(this.controller.bindingsReady, 100);
]]>
@@ -96,16 +96,16 @@
onset="document.getAnonymousElementByAttribute(this, 'anonid', 'unread').value = val; document.getAnonymousElementByAttribute(this, 'anonid', 'unread').collapsed = (val == 0);"
/>
- <method name="setFeed">
- <parameter name="feed"/>
+ <method name="setCollection">
+ <parameter name="collection"/>
<body>
<![CDATA[
- this.feed = feed;
- this.name = (feed.name && feed.name !=""?feed.name:feed.url);
- this.url = feed.url;
- this.preview = feed.preview;
- this.editable = feed.editable;
- this.unread = feed.getUnreadFeedItems().length;
+ this.collection = collection;
+ this.name = (collection.name && collection.name !=""?collection.name:collection.url);
+ this.url = collection.url;
+ this.preview = collection.preview;
+ this.editable = collection.editable;
+ this.unread = collection.getUnreadAddons().length;
]]>
</body>
</method>
@@ -114,14 +114,14 @@
</binding>
- <binding id="bandwagon-feeditem" extends="chrome://global/content/bindings/richlistbox.xml#richlistitem">
+ <binding id="bandwagon-addon" extends="chrome://global/content/bindings/richlistbox.xml#richlistitem">
<resources>
<stylesheet src="chrome://bandwagon/skin/extensionsOverlay.css"/>
</resources>
<content>
- <xul:stringbundle src="chrome://bandwagon/locale/bandwagonFeedItem.properties"
+ <xul:stringbundle src="chrome://bandwagon/locale/bandwagonAddon.properties"
anonid="stringbundle"/>
<xul:hbox flex="1">
@@ -144,13 +144,13 @@
</content>
<implementation>
- <field name="feedItem"/>
+ <field name="collectionItem"/>
<field name="_stringBundle">document.getAnonymousElementByAttribute(this, "anonid", "stringbundle");</field>
<constructor>
<![CDATA[
- if (this.feedItem)
- this.setFeedItem(this.feedItem);
+ if (this.collectionItem)
+ this.setAddon(this.collectionItem);
]]>
</constructor>
@@ -199,12 +199,12 @@
<property name="author"
onget="return (document.getAnonymousElementByAttribute(this, 'anonid', 'author')?document.getAnonymousElementByAttribute(this, 'anonid', 'author').value:'')"
- onset="if (document.getAnonymousElementByAttribute(this, 'anonid', 'author')) document.getAnonymousElementByAttribute(this, 'anonid', 'author').value = this._stringBundle.getFormattedString('bandwagon.feeditem.author', [val])"
+ onset="if (document.getAnonymousElementByAttribute(this, 'anonid', 'author')) document.getAnonymousElementByAttribute(this, 'anonid', 'author').value = this._stringBundle.getFormattedString('bandwagon.addon.author', [val])"
/>
<property name="category"
onget="return (document.getAnonymousElementByAttribute(this, 'anonid', 'category')?document.getAnonymousElementByAttribute(this, 'anonid', 'category').value:'')"
- onset="if (document.getAnonymousElementByAttribute(this, 'anonid', 'category')) document.getAnonymousElementByAttribute(this, 'anonid', 'category').value = this._stringBundle.getFormattedString('bandwagon.feeditem.category', [val])"
+ onset="if (document.getAnonymousElementByAttribute(this, 'anonid', 'category')) document.getAnonymousElementByAttribute(this, 'anonid', 'category').value = this._stringBundle.getFormattedString('bandwagon.addon.category', [val])"
/>
<property name="read"
@@ -226,36 +226,36 @@
if (diff < 60)
{
- sbString = "bandwagon.feeditem.added.justnow";
+ sbString = "bandwagon.addon.added.justnow";
}
else if (diff < 60 * 60)
{
- sbString = "bandwagon.feeditem.added.minute";
+ sbString = "bandwagon.addon.added.minute";
sbVal = Math.ceil(diff/60);
}
else if (diff < 60 * 60 * 24)
{
- sbString = "bandwagon.feeditem.added.hour";
+ sbString = "bandwagon.addon.added.hour";
sbVal = Math.floor(diff/60/60);
}
else if (diff < 60 * 60 * 24 * 7)
{
- sbString = "bandwagon.feeditem.added.day";
+ sbString = "bandwagon.addon.added.day";
sbVal = Math.floor(diff/60/60/24);
}
else if (diff < 60 * 60 * 24 * 30)
{
- sbString = "bandwagon.feeditem.added.week";
+ sbString = "bandwagon.addon.added.week";
sbVal = Math.floor(diff/60/60/24/7);
}
else if (diff < 60 * 60 * 24 * 356)
{
- sbString = "bandwagon.feeditem.added.month";
+ sbString = "bandwagon.addon.added.month";
sbVal = Math.floor(diff/60/60/24/30);
}
else
{
- sbString = "bandwagon.feeditem.added.year";
+ sbString = "bandwagon.addon.added.year";
sbVal = Math.floor(diff/60/60/24/356);
}
@@ -284,31 +284,31 @@
>
<setter>
<![CDATA[
- if (document.getAnonymousElementByAttribute(this, 'anonid', 'commentdesc')) document.getAnonymousElementByAttribute(this, 'anonid', 'commentdesc').firstChild.nodeValue = this._stringBundle.getFormattedString('bandwagon.feeditem.comment.description', [val.comment]);
- if (document.getAnonymousElementByAttribute(this, 'anonid', 'commentauthor')) document.getAnonymousElementByAttribute(this, 'anonid', 'commentauthor').value = this._stringBundle.getFormattedString('bandwagon.feeditem.comment.author', [val.author]);
+ if (document.getAnonymousElementByAttribute(this, 'anonid', 'commentdesc')) document.getAnonymousElementByAttribute(this, 'anonid', 'commentdesc').firstChild.nodeValue = this._stringBundle.getFormattedString('bandwagon.addon.comment.description', [val.comment]);
+ if (document.getAnonymousElementByAttribute(this, 'anonid', 'commentauthor')) document.getAnonymousElementByAttribute(this, 'anonid', 'commentauthor').value = this._stringBundle.getFormattedString('bandwagon.addon.comment.author', [val.author]);
]]>
</setter>
</property>
- <method name="setFeedItem">
- <parameter name="feedItem"/>
+ <method name="setAddon">
+ <parameter name="collectionItem"/>
<body>
<![CDATA[
- this.feedItem = feedItem;
- this.name = feedItem.name;
- this.guid = feedItem.guid;
- this.summary = feedItem.summary;
- this.description = feedItem.summary; // Use summary and not description
- this.iconURL = feedItem.icon;
- this.thumbnailURL = feedItem.thumbnail;
- this.author = (feedItem.author?feedItem.author:"Unknown");
- this.category = (feedItem.category?feedItem.category:"Unknown");
- this.dateAdded = feedItem.dateAdded;
- this.read = feedItem.read;
-
- if (feedItem.comments.length > 0)
+ this.collectionItem = collectionItem;
+ this.name = collectionItem.name;
+ this.guid = collectionItem.guid;
+ this.summary = collectionItem.summary;
+ this.description = collectionItem.summary; // Use summary and not description
+ this.iconURL = collectionItem.icon;
+ this.thumbnailURL = collectionItem.thumbnail;
+ this.author = (collectionItem.author?collectionItem.author:"Unknown");
+ this.category = (collectionItem.category?collectionItem.category:"Unknown");
+ this.dateAdded = collectionItem.dateAdded;
+ this.read = collectionItem.read;
+
+ if (collectionItem.comments.length > 0)
{
- this.comment = feedItem.comments[0];
+ this.comment = collectionItem.comments[0];
}
else
{
@@ -319,7 +319,7 @@
}
}
- var canInstall = feedItem.canInstall(Bandwagon.Util.getHostEnvironmentInfo());
+ var canInstall = collectionItem.canInstall(Bandwagon.Util.getHostEnvironmentInfo());
this.showVersionHelper(canInstall.type, canInstall.requiredVersion);
if (document.getAnonymousElementByAttribute(this, 'anonid', 'publish'))
@@ -339,7 +339,7 @@
if (publishButton)
{
publishButton.emailAddresses = Bandwagon.Controller.ExtensionsOverlay._getEmailAddresses();
- publishButton.writableFeeds = Bandwagon.Controller.ExtensionsOverlay._getWritableFeeds();
+ publishButton.writableCollections = Bandwagon.Controller.ExtensionsOverlay._getWritableCollections();
publishButton.invalidate();
}
]]>
@@ -354,44 +354,44 @@
if (document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefox')
&& document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning'))
{
- if (type == Bandwagon.Model.FeedItem.INSTALL_YES)
+ if (type == Bandwagon.Model.Addon.INSTALL_YES)
{
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefox').disabled = false;
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning').collapsed = true;
}
else
{
- if (type == Bandwagon.Model.FeedItem.INSTALL_NO_ADDON_IS_FOR_OLDER_VERSION)
+ if (type == Bandwagon.Model.Addon.INSTALL_NO_ADDON_IS_FOR_OLDER_VERSION)
{
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning').appendChild(
- document.createTextNode(this._stringBundle.getString("bandwagon.feeditem.olderversionsoffirefox")));
+ document.createTextNode(this._stringBundle.getString("bandwagon.addon.olderversionsoffirefox")));
}
- else if (type == Bandwagon.Model.FeedItem.INSTALL_NO_UPGRADE_TO_USE_THIS_VERSION)
+ else if (type == Bandwagon.Model.Addon.INSTALL_NO_UPGRADE_TO_USE_THIS_VERSION)
{
var atffwl = document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarninglink');
- atffwl.value = this._stringBundle.getFormattedString("bandwagon.feeditem.upgradetofirefoxn1", [version]);
+ atffwl.value = this._stringBundle.getFormattedString("bandwagon.addon.upgradetofirefoxn1", [version]);
atffwl.collapsed = false;
- atffwl.addEventListener("click", function() { Bandwagon.Controller.FeedsPane.doUpgradeToFirefoxN(version); }, true);
+ atffwl.addEventListener("click", function() { Bandwagon.Controller.CollectionsPane.doUpgradeToFirefoxN(version); }, true);
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning').appendChild(
- document.createTextNode(this._stringBundle.getString("bandwagon.feeditem.upgradetofirefoxn2")));
+ document.createTextNode(this._stringBundle.getString("bandwagon.addon.upgradetofirefoxn2")));
}
- else if (type == Bandwagon.Model.FeedItem.INSTALL_NO_MUST_DOWNLOAD_BETA)
+ else if (type == Bandwagon.Model.Addon.INSTALL_NO_MUST_DOWNLOAD_BETA)
{
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning').appendChild(
- document.createTextNode(this._stringBundle.getFormattedString("bandwagon.feeditem.requiresfirefoxbeta1", [version])));
+ document.createTextNode(this._stringBundle.getFormattedString("bandwagon.addon.requiresfirefoxbeta1", [version])));
var atffwl = document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarninglink');
- atffwl.value = this._stringBundle.getFormattedString("bandwagon.feeditem.requiresfirefoxbeta2", [version]);
+ atffwl.value = this._stringBundle.getFormattedString("bandwagon.addon.requiresfirefoxbeta2", [version]);
atffwl.collapsed = false;
- atffwl.addEventListener("click", function() { Bandwagon.Controller.FeedsPane.doDownloadFirefoxNBeta(version); }, true);
+ atffwl.addEventListener("click", function() { Bandwagon.Controller.CollectionsPane.doDownloadFirefoxNBeta(version); }, true);
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning').appendChild(atffwl);
}
- else if (type == Bandwagon.Model.FeedItem.INSTALL_NO_NOT_COMPATIBLE_OS)
+ else if (type == Bandwagon.Model.Addon.INSTALL_NO_NOT_COMPATIBLE_OS)
{
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefoxwarning').appendChild(
- document.createTextNode(this._stringBundle.getFormattedString("bandwagon.feeditem.notcompatible", [version])));
+ document.createTextNode(this._stringBundle.getFormattedString("bandwagon.addon.notcompatible", [version])));
}
document.getAnonymousElementByAttribute(this, 'anonid', 'addtofirefox').disabled = true;
@@ -447,10 +447,10 @@
</implementation>
</binding>
- <binding id="bandwagon-feeditem-expanded" extends="chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-feeditem">
+ <binding id="bandwagon-addon-expanded" extends="chrome://bandwagon/content/ui/bindings/bandwagon.xml#bandwagon-addon">
<content>
- <xul:stringbundle src="chrome://bandwagon/locale/bandwagonFeedItem.properties"
+ <xul:stringbundle src="chrome://bandwagon/locale/bandwagonAddon.properties"
anonid="stringbundle"/>
<xul:hbox flex="1">
@@ -474,7 +474,7 @@
</xul:hbox>
<xul:hbox align="stretch"
anonid="fulldesc"
- class="feed-item-details"
+ class="collection-item-details"
flex="1">
<xul:vbox pack="start">
<xul:hbox anonid="bandwagonThumbnailContainer"
@@ -488,12 +488,12 @@
<xul:description anonid="commentdesc"> </xul:description>
<xul:label anonid="commentauthor" flex="1" class="right"/>
<xul:description anonid="description">
- <xul:label anonid="learnmore" class="text-link" value="&feeditem.moreinfo;" onclick="Bandwagon.Controller.FeedsPane.doMoreInfo()"/>
+ <xul:label anonid="learnmore" class="text-link" value="&addon.moreinfo;" onclick="Bandwagon.Controller.CollectionsPane.doMoreInfo()"/>
</xul:description>
<xul:spacer flex="1"/>
<xul:hbox pack="end" class="publishButton">
<xul:bandwagonPublishButton anonid="publish" label="&publishto.label;"/>
- <xul:button anonid="addtofirefox" label="&feeditem.addtofirefox;" oncommand="Bandwagon.Controller.FeedsPane.doAddToFirefox()"/>
+ <xul:button anonid="addtofirefox" label="&addon.addtofirefox;" oncommand="Bandwagon.Controller.CollectionsPane.doAddToFirefox()"/>
</xul:hbox>
<xul:description anonid="addtofirefoxwarning" class="right">
<xul:label anonid="addtofirefoxwarninglink" class="text-link" collapsed="true"/>
@@ -533,9 +533,9 @@
anonid="publishButton1"
class="publishButton"
collapsed="true">
- <xul:menupopup anonid="writableFeeds">
- <!-- writable feeds go here -->
- <xul:menuseparator anonid="writableFeedSeparator"/>
+ <xul:menupopup anonid="writableCollections">
+ <!-- writable collections go here -->
+ <xul:menuseparator anonid="writableCollectionSeparator"/>
<xul:menu label="&email.address.label;" anonid="emailAddressMenu1">
<xul:menupopup anonid="emailAddresses1">
<!-- email addresses go here -->
@@ -562,11 +562,11 @@
<implementation>
<field name="emailAddresses"/>
- <field name="writableFeeds"/>
+ <field name="writableCollections"/>
<constructor>
<![CDATA[
- if (this.emailAddresses && this.writableFeeds)
+ if (this.emailAddresses && this.writableCollections)
{
this.invalidate();
}
@@ -578,8 +578,8 @@
<![CDATA[
const XULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
- var elemWritableFeedsPopup = document.getAnonymousElementByAttribute(this, "anonid", "writableFeeds");
- var elemWritableFeedSeparator = document.getAnonymousElementByAttribute(this, "anonid", "writableFeedSeparator");
+ var elemWritableCollectionsPopup = document.getAnonymousElementByAttribute(this, "anonid", "writableCollections");
+ var elemWritableCollectionSeparator = document.getAnonymousElementByAttribute(this, "anonid", "writableCollectionSeparator");
var elemEmailAddressesPopup1 = document.getAnonymousElementByAttribute(this, "anonid", "emailAddresses1");
var elemEmailAddressesPopup2 = document.getAnonymousElementByAttribute(this, "anonid", "emailAddresses2");
var elemEmailAddressSeparator1 = document.getAnonymousElementByAttribute(this, "anonid", "emailAddressSeparator1");
@@ -591,8 +591,8 @@
// populate the email address menu
- var activeEmailMenu = (this.writableFeeds.length==0?elemEmailAddressesPopup2:elemEmailAddressesPopup1);
- var activeEmailAddressSeparator = (this.writableFeeds.length==0?elemEmailAddressSeparator2:elemEmailAddressSeparator1);
+ var activeEmailMenu = (this.writableCollections.length==0?elemEmailAddressesPopup2:elemEmailAddressesPopup1);
+ var activeEmailAddressSeparator = (this.writableCollections.length==0?elemEmailAddressSeparator2:elemEmailAddressSeparator1);
if (this.emailAddresses.length)
{
@@ -621,30 +621,30 @@
activeEmailAddressSeparator.collapsed = true;
}
- if (this.writableFeeds.length)
+ if (this.writableCollections.length)
{
- // populate the feeds menu
+ // populate the collections menu
- function createFeedCallbackFunction(feed)
+ function createCollectionCallbackFunction(collection)
{
- return function() { Bandwagon.Controller.ExtensionsOverlay.doPublishToFeed(feed); }
+ return function() { Bandwagon.Controller.ExtensionsOverlay.doPublishToCollection(collection); }
}
- for (var i=0; i<this.writableFeeds.length; i++)
+ for (var i=0; i<this.writableCollections.length; i++)
{
- var feed = this.writableFeeds[i];
+ var collection = this.writableCollections[i];
- if (document.getAnonymousElementByAttribute(this, "anonid", "bandwagon-feed-" + feed.url))
+ if (document.getAnonymousElementByAttribute(this, "anonid", "bandwagon-collection-" + collection.url))
continue;
- var callback = createFeedCallbackFunction(feed);
+ var callback = createCollectionCallbackFunction(collection);
- var elemWritableFeed = document.createElementNS(XULNS, "menuitem");
- elemWritableFeed.setAttribute("label", (feed.name?feed.name:feed.url));
- elemWritableFeed.setAttribute("anonid", "bandwagon-feed-" + feed.url);
- elemWritableFeed.addEventListener("command", callback, true);
+ var elemWritableCollection = document.createElementNS(XULNS, "menuitem");
+ elemWritableCollection.setAttribute("label", (collection.name?collection.name:collection.url));
+ elemWritableCollection.setAttribute("anonid", "bandwagon-collection-" + collection.url);
+ elemWritableCollection.addEventListener("command", callback, true);
- elemWritableFeedsPopup.insertBefore(elemWritableFeed, elemWritableFeedSeparator);
+ elemWritableCollectionsPopup.insertBefore(elemWritableCollection, elemWritableCollectionSeparator);
}
elemPublishButton1.collapsed = false;
diff --git a/bandwagon/content/ui/collectionsPaneController.js b/bandwagon/content/ui/collectionsPaneController.js
index 3ec81db..67b2e79 100644
--- a/bandwagon/content/ui/collectionsPaneController.js
+++ b/bandwagon/content/ui/collectionsPaneController.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/ui/dialog.js b/bandwagon/content/ui/dialog.js
index 33e635c..84d096f 100644
--- a/bandwagon/content/ui/dialog.js
+++ b/bandwagon/content/ui/dialog.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
diff --git a/bandwagon/content/ui/overlays/extensionsOverlay.xul b/bandwagon/content/ui/overlays/extensionsOverlay.xul
index 8576a03..a008812 100644
--- a/bandwagon/content/ui/overlays/extensionsOverlay.xul
+++ b/bandwagon/content/ui/overlays/extensionsOverlay.xul
@@ -46,7 +46,7 @@
<script src="chrome://bandwagon/content/ui/dialog.js"/>
<script src="chrome://bandwagon/content/ui/overlays/extensionsOverlayController.js"/>
- <script src="chrome://bandwagon/content/ui/feedsPaneController.js"/>
+ <script src="chrome://bandwagon/content/ui/collectionsPaneController.js"/>
<stringbundleset>
<stringbundle id="bandwagon-strings" src="chrome://bandwagon/locale/extensionOverlay.properties"/>
@@ -55,10 +55,10 @@
<stack id="topStackBar">
<radiogroup id="viewGroup">
- <radio id="bandwagon-feeds-view"
- label="&feeds.label;"
+ <radio id="bandwagon-collections-view"
+ label="&collections.label;"
insertbefore="extensions-view"
- oncommand="showView('bandwagon-feeds');"
+ oncommand="showView('bandwagon-collections');"
persist="last-selected"/>
<radio id="search-view"
label="&search.label.bandwagon;"
@@ -69,65 +69,65 @@
</stack>
<vbox id="extensionsBox">
- <hbox id="bandwagon-feeds-panel" hidden="true" flex="1">
- <vbox id="bandwagon-feeds-list-box" persist="width">
- <richlistbox id="bandwagon-feeds-list"
+ <hbox id="bandwagon-collections-panel" hidden="true" flex="1">
+ <vbox id="bandwagon-collections-list-box" persist="width">
+ <richlistbox id="bandwagon-collections-list"
seltype="single"
style="min-width: 14em; width: 16em; max-width: 36em;"
flex="1"/>
- <toolbox class="bandwagon-feeds-toolbox">
+ <toolbox class="bandwagon-collections-toolbox">
<toolbar pack="start"
align="center">
<toolbarbutton id="bandwagon-button-subscribe"
tooltiptext="&subscribe.label;"
- oncommand="Bandwagon.Controller.FeedsPane.doSubscribe();"/>
+ oncommand="Bandwagon.Controller.CollectionsPane.doSubscribe();"/>
<toolbarbutton id="bandwagon-button-update-all"
tooltiptext="&reload.label;"
- oncommand="Bandwagon.Controller.FeedsPane.doUpdateAll();"/>
+ oncommand="Bandwagon.Controller.CollectionsPane.doUpdateAll();"/>
<toolbarbutton id="bandwagon-button-settings"
tooltiptext="&settings.label;"
- oncommand="Bandwagon.Controller.FeedsPane.doSettings();"/>
+ oncommand="Bandwagon.Controller.CollectionsPane.doSettings();"/>
</toolbar>
</toolbox>
</vbox>
<splitter id="bandwagon-sidebar-splitter" />
- <notificationbox flex="1" id="bandwagon-feeds-notification">
+ <notificationbox flex="1" id="bandwagon-collections-notification">
<hbox pack="end">
<label id="bandwagon-button-viewsite"
value="&view.label;"
class="text-link"
- onclick="Bandwagon.Controller.FeedsPane.doViewSite();"/>
+ onclick="Bandwagon.Controller.CollectionsPane.doViewSite();"/>
<separator id="bandwagon-link-splitter"/>
<label id="bandwagon-button-remove"
value="&unsubscribe.label;"
class="text-link"
- onclick="Bandwagon.Controller.FeedsPane.doRemove();"/>
+ onclick="Bandwagon.Controller.CollectionsPane.doRemove();"/>
</hbox>
- <vbox id="bandwagon-feed-header">
- <label id="bandwagon-feed-title"/>
- <label id="bandwagon-feed-description"/>
+ <vbox id="bandwagon-collection-header">
+ <label id="bandwagon-collection-title"/>
+ <label id="bandwagon-collection-description"/>
</vbox>
- <deck id="bandwagon-feed-deck" selectedIndex="0" flex="1">
+ <deck id="bandwagon-collection-deck" selectedIndex="0" flex="1">
<hbox flex="1">
- <richlistbox id="bandwagon-feeditems-list"
+ <richlistbox id="bandwagon-collectionitems-list"
seltype="single"
flex="1"/>
</hbox>
<vbox flex="1" align="center" pack="center">
- <label value="&nofeedssubscribed.label;"/>
- <button label="&clicktosubscribe.label;" oncommand="Bandwagon.Controller.FeedsPane.doSubscribe();"/>
+ <label value="&nocollectionssubscribed.label;"/>
+ <button label="&clicktosubscribe.label;" oncommand="Bandwagon.Controller.CollectionsPane.doSubscribe();"/>
</vbox>
<vbox flex="1" align="center" pack="center">
- <label class="userfeedback" value="&feedisloading.label;"/>
+ <label class="usercollectionback" value="&collectionisloading.label;"/>
<image src="chrome://bandwagon/skin/images/spinner.gif"/>
</vbox>
<vbox flex="1" align="center" pack="center">
<image src="chrome://bandwagon/skin/images/information.png"/>
- <label class="userfeedback" value="&feedhasnoitems.label;"/>
+ <label class="usercollectionback" value="&collectionhasnoitems.label;"/>
</vbox>
<vbox flex="1" align="center" pack="center">
<image src="chrome://bandwagon/skin/images/error.png"/>
- <label class="userfeedback" value="&feedhaserror.label;"/>
+ <label class="usercollectionback" value="&collectionhaserror.label;"/>
</vbox>
</deck>
</notificationbox>
diff --git a/bandwagon/content/ui/overlays/extensionsOverlayController.js b/bandwagon/content/ui/overlays/extensionsOverlayController.js
index 3cb08b5..05a09d6 100644
--- a/bandwagon/content/ui/overlays/extensionsOverlayController.js
+++ b/bandwagon/content/ui/overlays/extensionsOverlayController.js
@@ -54,7 +54,7 @@ Bandwagon.Controller.ExtensionsOverlay.init = function()
// So lets hackily hide ours in that circumstance
var extView = document.getElementById("extensions-view");
- var bfv = document.getElementById("bandwagon-feeds-view");
+ var bfv = document.getElementById("bandwagon-collections-view");
var lsi = extView.ownerDocument.defaultView.getComputedStyle( extView, '' ).getPropertyCSSValue("list-style-image").cssText;
if (lsi == "none")
@@ -88,23 +88,23 @@ Bandwagon.Controller.ExtensionsOverlay.init = function()
setTimeout(function()
{
- Bandwagon.Controller.ExtensionsOverlay._showFeedsPaneView();
- Bandwagon.Controller.FeedsPane.doShowFeedPreview(inArgs.subscribe);
+ Bandwagon.Controller.ExtensionsOverlay._showCollectionsPaneView();
+ Bandwagon.Controller.CollectionsPane.doShowCollectionPreview(inArgs.subscribe);
},
500);
}
- else if (inArgs.selectFeed)
+ else if (inArgs.selectCollection)
{
- Bandwagon.Logger.debug("Have window argument selectFeed = " + inArgs.selectFeed);
+ Bandwagon.Logger.debug("Have window argument selectCollection = " + inArgs.selectCollection);
- if (bandwagonService.feeds[inArgs.selectFeed])
+ if (bandwagonService.collections[inArgs.selectCollection])
{
- Bandwagon.Controller.FeedsPane.preferredFeed = bandwagonService.feeds[inArgs.selectFeed];
+ Bandwagon.Controller.ColllectionsPane.preferredCollection = bandwagonService.collections[inArgs.selectCollection];
}
setTimeout(function()
{
- Bandwagon.Controller.ExtensionsOverlay._showFeedsPaneView();
+ Bandwagon.Controller.ExtensionsOverlay._showCollectionsPaneView();
},
500);
}
@@ -112,16 +112,16 @@ Bandwagon.Controller.ExtensionsOverlay.init = function()
}
}
-Bandwagon.Controller.ExtensionsOverlay.doPublishToFeed = function(feed)
+Bandwagon.Controller.ExtensionsOverlay.doPublishToCollection = function(collections)
{
- Bandwagon.Logger.debug("In Bandwagon.Controller.ExtensionsOverlay.doPublishToFeed() with feed = '" + feed.url + "'");
+ Bandwagon.Logger.debug("In Bandwagon.Controller.ExtensionsOverlay.doPublishToCollection() with collection = '" + collection.toString() + "'");
var extension = Bandwagon.Controller.ExtensionsOverlay._getSelectedExtension();
var params =
{
publishType: 1,
- publishDestination: feed,
+ publishDestination: collection,
publishExtension: extension
};
@@ -150,15 +150,15 @@ Bandwagon.Controller.ExtensionsOverlay._getSelectedExtension = function()
if (document.getElementById("extensionsView").selectedItem)
{
- var selectedFeedItem = document.getElementById("extensionsView").selectedItem;
- extension.guid = selectedFeedItem.getAttribute("addonID");
- extension.name = selectedFeedItem.getAttribute("name");
+ var selectedAddon = document.getElementById("extensionsView").selectedItem;
+ extension.guid = selectedAddon.getAttribute("addonID");
+ extension.name = selectedAddon.getAttribute("name");
}
- else if (Bandwagon.Controller.FeedsPane && Bandwagon.Controller.FeedsPane.elemBandwagonFeedItems.selectedItem)
+ else if (Bandwagon.Controller.CollectionsPane && Bandwagon.Controller.CollectionsPane.elemBandwagonAddons.selectedItem)
{
- var selectedFeedItem = Bandwagon.Controller.FeedsPane.elemBandwagonFeedItems.selectedItem;
- extension.guid = selectedFeedItem.guid;
- extension.name = selectedFeedItem.name;
+ var selectedAddon = Bandwagon.Controller.CollectionsPane.elemBandwagonAddons.selectedItem;
+ extension.guid = selectedAddon.guid;
+ extension.name = selectedAddon.name;
}
else
{
@@ -241,7 +241,7 @@ Bandwagon.Controller.ExtensionsOverlay._invalidatePublishButton = function()
}
Bandwagon.Controller.ExtensionsOverlay._publishButton.emailAddresses = Bandwagon.Controller.ExtensionsOverlay._getEmailAddresses();
- Bandwagon.Controller.ExtensionsOverlay._publishButton.writableFeeds = Bandwagon.Controller.ExtensionsOverlay._getWritableFeeds();
+ Bandwagon.Controller.ExtensionsOverlay._publishButton.writableCollections = Bandwagon.Controller.ExtensionsOverlay._getWritableCollections();
try
{
@@ -250,21 +250,21 @@ Bandwagon.Controller.ExtensionsOverlay._invalidatePublishButton = function()
catch (e) {}
}
-Bandwagon.Controller.ExtensionsOverlay._getWritableFeeds = function()
+Bandwagon.Controller.ExtensionsOverlay._getWritableCollections = function()
{
- var writableFeeds = [];
+ var writableCollections = [];
- for (var id in bandwagonService.feeds)
+ for (var id in bandwagonService.Collections)
{
- if (1 || (bandwagonService.feeds[id].editable && !bandwagonService.feeds[id].preview))
+ if (1 || (bandwagonService.Collections[id].editable && !bandwagonService.Collections[id].preview))
{
- writableFeeds.push(bandwagonService.feeds[id]);
+ writableCollections.push(bandwagonService.Collections[id]);
}
}
- writableFeeds.sort();
+ writableCollections.sort();
- return writableFeeds;
+ return writableCollections;
}
Bandwagon.Controller.ExtensionsOverlay._getEmailAddresses = function()
@@ -276,12 +276,12 @@ Bandwagon.Controller.ExtensionsOverlay._getEmailAddresses = function()
return previouslySharedEmailAddresses;
}
-Bandwagon.Controller.ExtensionsOverlay._showFeedsPaneView = function()
+Bandwagon.Controller.ExtensionsOverlay._showCollectionsPaneView = function()
{
- Bandwagon.Logger.debug("in _showFeedsPaneView()");
+ Bandwagon.Logger.debug("in _showCollectionsPaneView()");
- updateLastSelected("bandwagon-feeds");
- gView = "bandwagon-feeds";
+ updateLastSelected("bandwagon-collections");
+ gView = "bandwagon-collections";
document.getElementById("installFileButton").hidden = true;
document.getElementById("checkUpdatesAllButton").hidden = true;
@@ -301,12 +301,12 @@ Bandwagon.Controller.ExtensionsOverlay._showFeedsPaneView = function()
AddonsViewBuilder.clearChildren(gExtensionsView);
- document.getElementById("bandwagon-feeds-panel").hidden = false;
+ document.getElementById("bandwagon-collections-panel").hidden = false;
updateGlobalCommands();
- Bandwagon.Controller.FeedsPane.init();
- Bandwagon.Controller.FeedsPane.onViewSelect();
+ Bandwagon.Controller.CollectionsPane.init();
+ Bandwagon.Controller.CollectionsPane.onViewSelect();
}
// magic
@@ -315,13 +315,13 @@ Bandwagon.Controller.ExtensionsOverlay._defaultShowView = showView;
Bandwagon.Controller.ExtensionsOverlay._showView = function(aView)
{
- if (aView == "bandwagon-feeds")
+ if (aView == "bandwagon-collections")
{
- Bandwagon.Controller.ExtensionsOverlay._showFeedsPaneView();
+ Bandwagon.Controller.ExtensionsOverlay._showCollectionsPaneView();
}
else
{
- document.getElementById("bandwagon-feeds-panel").hidden = true;
+ document.getElementById("bandwagon-collections-panel").hidden = true;
document.getElementById("extensionsView").hidden = false;
document.getElementById("extensionsView").parentNode.hidden = false;
diff --git a/bandwagon/locale/en-US/extensionsOverlay.dtd b/bandwagon/locale/en-US/extensionsOverlay.dtd
index 135ab14..72d1394 100644
--- a/bandwagon/locale/en-US/extensionsOverlay.dtd
+++ b/bandwagon/locale/en-US/extensionsOverlay.dtd
@@ -49,8 +49,8 @@
<!ENTITY nocollectionssubscribed.label "You are not subscribed to any subscriptions">
<!ENTITY clicktosubscribe.label "Browse subscriptions">
<!ENTITY collectionisloading.label "Retrieving subscription">
-<!ENTITY collectionhasnoitems.label "This feed contains no items.">
-<!ENTITY collectionhaserror.label "This feed failed to load because it contains errors.">
+<!ENTITY collectionhasnoitems.label "This collection contains no add-ons.">
+<!ENTITY collectionhaserror.label "This collection cannot be displayed because it contains errors.">
<!ENTITY publishto.label "Publish to">
<!ENTITY email.address.label "E-mail Address">
diff --git a/bandwagon/skin/extensionsOverlay.css b/bandwagon/skin/extensionsOverlay.css
index 8f79488..9991d7f 100644
--- a/bandwagon/skin/extensionsOverlay.css
+++ b/bandwagon/skin/extensionsOverlay.css
@@ -35,16 +35,16 @@
*
* ***** END LICENSE BLOCK ***** */
-radio#bandwagon-feeds-view {
+radio#bandwagon-collections-view {
list-style-image: url("chrome://bandwagon/skin/images/icon32.png");
-moz-image-region: rect(0px, 32px, 32px, 0px);
}
-radio#bandwagon-feeds-view:hover, radio#bandwagon-feeds-view[selected="true"] {
+radio#bandwagon-collections-view:hover, radio#bandwagon-collections-view[selected="true"] {
-moz-image-region: rect(0px, 32px, 32px, 0px);
}
-radio[noimage="true"]#bandwagon-feeds-view {
+radio[noimage="true"]#bandwagon-collections-view {
list-style-image: none;
-moz-image-region: rect(0 0 0 0);
}
@@ -64,12 +64,12 @@ radio[noimage="true"]#bandwagon-feeds-view {
background-image: none !important;
}
-#bandwagon-feeds-list {
+#bandwagon-collections-list {
margin-top: 0;
margin-left: 0;
}
-#bandwagon-feeditems-list {
+#bandwagon-addons-list {
border: 2px solid;
border-left: 0px !important;
-moz-border-top-colors: ThreeDShadow ThreeDDarkShadow;
@@ -79,17 +79,17 @@ radio[noimage="true"]#bandwagon-feeds-view {
/*overflow: auto;*/
}
-#bandwagon-feed-title {
+#bandwagon-collection-title {
font-size: 150%;
}
-#bandwagon-feed-title,
-#bandwagon-feed-description,
-#bandwagon-feed-header {
+#bandwagon-collection-title,
+#bandwagon-collection-description,
+#bandwagon-collection-header {
background: -moz-dialog;
}
-bandwagonFeed {
+bandwagonCollection {
padding-top: 6px;
padding-bottom: 6px;
-moz-padding-start: 7px;
@@ -97,7 +97,7 @@ bandwagonFeed {
min-height: 25px;
}
-bandwagonFeed[view="settings"] {
+bandwagonCollection[view="settings"] {
padding-top: 0;
padding-bottom: 0;
-moz-padding-start: 0;
@@ -105,21 +105,21 @@ bandwagonFeed[view="settings"] {
min-height: 0;
}
-bandwagonFeed[selected="true"] {
+bandwagonCollection[selected="true"] {
background-color: -moz-cellhighlight;
color: -moz-cellhighlighttext;
}
-bandwagonFeed[preview="true"] label[anonid="name"] {
+bandwagonCollection[preview="true"] label[anonid="name"] {
font-style: italic;
}
-richlistbox:focus > bandwagonFeed[selected="true"] {
+richlistbox:focus > bandwagonCollection[selected="true"] {
background-color: Highlight;
color: HighlightText;
}
-bandwagonFeed label[anonid="unread"] {
+bandwagonCollection label[anonid="unread"] {
background-color: blue;
color: white;
min-width: 1.7em;
@@ -127,12 +127,12 @@ bandwagonFeed label[anonid="unread"] {
-moz-border-radius: 40%;
}
-bandwagonFeed[view="settings"] label[anonid="unread"] {
+bandwagonCollection[view="settings"] label[anonid="unread"] {
display: none;
}
-bandwagonFeedItem,
-bandwagonFeedItemExpanded {
+bandwagonAddon,
+bandwagonAddonExpanded {
padding-top: 6px;
padding-bottom: 6px;
-moz-padding-start: 7px;
@@ -141,28 +141,28 @@ bandwagonFeedItemExpanded {
border-bottom: 1px dotted #C0C0C0;
}
-bandwagonFeedItemExpanded {
+bandwagonAddonExpanded {
background-color: -moz-cellhighlight;
color: -moz-cellhighlighttext;
}
-richlistbox:focus > bandwagonFeedItemExpanded {
+richlistbox:focus > bandwagonAddonExpanded {
background-color: Highlight;
color: HighlightText;
}
-bandwagonFeedItem[read="false"] {
+bandwagonAddon[read="false"] {
background-color: #fdf2ab;
color: #585620;
}
-bandwagonFeedItem .right,
-bandwagonFeedItemExpanded .right {
+bandwagonAddon .right,
+bandwagonAddonExpanded .right {
text-align: right;
}
-bandwagonFeedItem .icon,
-bandwagonFeedItemExpanded .icon {
+bandwagonAddon .icon,
+bandwagonAddonExpanded .icon {
width: 32px;
height: 32px;
max-width: 32px;
@@ -171,8 +171,8 @@ bandwagonFeedItemExpanded .icon {
min-height: 32px;
}
-bandwagonFeedItem .name,
-bandwagonFeedItemExpanded .name {
+bandwagonAddon .name,
+bandwagonAddonExpanded .name {
font-size: 110%;
}
@@ -182,7 +182,7 @@ bandwagonFeedItemExpanded .name {
height: 32px;
}
-.feed-item-details {
+.addon-details {
margin-top: 5px;
margin-bottom: 5px;
-moz-margin-start: 6px;
diff --git a/bandwagon/skin/global.css b/bandwagon/skin/global.css
index bc8df95..461c0cb 100644
--- a/bandwagon/skin/global.css
+++ b/bandwagon/skin/global.css
@@ -34,7 +34,7 @@
*
* ***** END LICENSE BLOCK ***** */
-.bandwagon-feeds-toolbox {
+.bandwagon-collections-toolbox {
-moz-appearance: none;
background-color: transparent !important;
border: 0px;
diff --git a/bandwagon/skin/settings.css b/bandwagon/skin/settings.css
index 717d6d3..0c4e411 100644
--- a/bandwagon/skin/settings.css
+++ b/bandwagon/skin/settings.css
@@ -47,12 +47,12 @@ radio[pane=auto] {
-moz-image-region: rect(0px, 224px, 32px, 192px)
}
-#feeds-list {
+#collections-list {
min-width: 10em;
max-width: 10em;
}
-#feed-name {
+#collection-name {
font-weight: bold;
font-size: larger;
}
@@ -61,10 +61,10 @@ radio[pane=auto] {
padding-left: 15px;
}
-#add-feed-button {
+#add-collection-button {
list-style-image: url("chrome://bandwagon/skin/images/plus.png");
}
-#remove-feed-button {
+#remove-collection-button {
list-style-image: url("chrome://bandwagon/skin/images/twisty-open.png");
}
diff --git a/bandwagon/content/ui/overlays/browserOverlayController.js b/bandwagon/content/ui/overlays/browserOverlayController.js
index d2f3761..ada0300 100644
--- a/bandwagon/content/ui/overlays/browserOverlayController.js
+++ b/bandwagon/content/ui/overlays/browserOverlayController.js
@@ -14,11 +14,11 @@
* The Original Code is bandwagon.
*
* The Initial Developer of the Original Code is
- * David McNamara.
+ * Mozilla Corporation.
* Portions created by the Initial Developer are Copyright (C) 2008
* the Initial Developer. All Rights Reserved.
*
- * Contributor(s):
+ * Contributor(s): David McNamara
*
* Alternatively, the contents of this file may be used under the terms of
* either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -88,11 +88,11 @@ Bandwagon.Controller.BrowserOverlay.handleSubscribeEvent = function(event)
{
if (event.target && event.target.getAttribute("href"))
{
- var feedURL = event.target.getAttribute("href");
+ var collectionURL = event.target.getAttribute("href");
- Bandwagon.Logger.info("Received subscribe event for feed: " + feedURL);
+ Bandwagon.Logger.info("Received subscribe event for collection: " + collectionURL);
- Bandwagon.Controller.BrowserOverlay._openExtensionManagerFeedsPaneWithSubscribe(feedURL);
+ Bandwagon.Controller.BrowserOverlay._openExtensionManagerCollectionsPaneWithSubscribe(collectionURL);
}
else
{
@@ -100,7 +100,7 @@ Bandwagon.Controller.BrowserOverlay.handleSubscribeEvent = function(event)
}
}
-Bandwagon.Controller.BrowserOverlay._openExtensionManagerFeedsPaneWithSubscribe = function(feedURL)
+Bandwagon.Controller.BrowserOverlay._openExtensionManagerCollectionsPaneWithSubscribe = function(collectionURL)
{
const EMTYPE = "Extension:Manager";
var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
@@ -109,21 +109,21 @@ Bandwagon.Controller.BrowserOverlay._openExtensionManagerFeedsPaneWithSubscribe
if (theEM)
{
// extensions manager window already open - focus, show feeds pane, call doShowFeedPreview
theEM.focus();
- theEM.showView('bandwagon-feeds');
+ theEM.showView('bandwagon-collections');
- setTimeout(function() { Bandwagon.Controller.FeedsPane.doShowFeedPreview(feedURL); }, 500);
+ setTimeout(function() { Bandwagon.Controller.CollectionsPane.doShowCollectionPreview(collectionURL); }, 500);
}
else
{
// extensions manager window NOT already open - open with 'subscribe' argument (this will show feeds pane, call doShowFeedPreview)
const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
- window.openDialog(EMURL, "", EMFEATURES, {subscribe: feedURL});
+ window.openDialog(EMURL, "", EMFEATURES, {subscribe: collectionURL});
}
}
@@ -144,18 +144,18 @@ Bandwagon.Controller.BrowserOverlay.openFirstRunLandingPage = function()
1000);
}
-Bandwagon.Controller.BrowserOverlay.showNewFeedItemsAlert = function(feed)
+Bandwagon.Controller.BrowserOverlay.showNewAddonsAlert = function(collection)
{
- Bandwagon.Logger.debug("in showNewFeedItemsAlert()");
+ Bandwagon.Logger.debug("in showNewAddonsAlert()");
var bandwagonStrings = document.getElementById("bandwagon-strings");
var alertsService = Components.classes["@mozilla.org/alerts-service;1"]
.getService(Components.interfaces.nsIAlertsService);
- var unnotifiedCount = feed.getUnnotifiedFeedItems().length;
- var feedName = (feed.name?feed.name:feed.url);
- var feedURL = feed.url;
+ var unnotifiedCount = collection.getUnnotifiedAddons().length;
+ var collectionName = (collection.name?collection.name:collection.url);
+ var collectionURL = collection.url;
var listener =
{
@@ -163,7 +163,7 @@ Bandwagon.Controller.BrowserOverlay.showNewFeedItemsAlert = function(feed)
{
if (topic == "alertclickcallback")
{
- var feedURL = data;
+ var collectionURL = data;
const EMTYPE = "Extension:Manager";
var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
@@ -173,22 +173,22 @@ Bandwagon.Controller.BrowserOverlay.showNewFeedItemsAlert = function(feed)
if (theEM)
{
theEM.focus();
- theEM.showView('bandwagon-feeds');
+ theEM.showView('bandwagon-collections');
- // if the em is open, select the bandwagon-feeds pane, but don't select the feed itself.
+ // if the em is open, select the bandwagon-collections pane, but don't select the collection itself.
// the user will be notified by the unread count in the left hand side bar
- //theEM.setTimeout(function() { Bandwagon.Controller.FeedsPane._selectFeed(feed); }, 500);
+ //theEM.setTimeout(function() { Bandwagon.Controller.CollectionsPane._selectCollection(collection); }, 500);
}
else
{
const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
// the em is not open - open it, and select this feed
if (window)
- window.openDialog(EMURL, "", EMFEATURES, {selectFeed: feedURL});
+ window.openDialog(EMURL, "", EMFEATURES, {selectCollection: collectionURL});
else
Bandwagon.Logger.error("No browser windows open - can't open EM");
}
@@ -200,11 +200,11 @@ Bandwagon.Controller.BrowserOverlay.showNewFeedItemsAlert = function(feed)
try
{
alertsService.showAlertNotification(
- "chrome://bandwagon/skin/images/tango-addonfeed-32x32.png",
- bandwagonStrings.getString("newfeeditems.alert.title"),
- bandwagonStrings.getFormattedString("newfeeditems.alert.text", [feedName]),
+ "chrome://bandwagon/skin/images/icon32.png",
+ bandwagonStrings.getString("newaddons.alert.title"),
+ bandwagonStrings.getFormattedString("newaddons.alert.text", [collectionName]),
true,
- feedURL,
+ collectionURL,
listener
);
}
@@ -109,21 +109,21 @@ Bandwagon.Controller.BrowserOverlay._openExtensionManagerFeedsPaneWithSubscribe
if (theEM)
{
- // extensions manager window already open - focus, show feeds pane, call doShowFeedPreview
+ // extensions manager window already open - focus, show collections pane, call doShowCollectionPreview
theEM.focus();
@@ -109,21 +109,21 @@ Bandwagon.Controller.BrowserOverlay._openExtensionManagerFeedsPaneWithSubscribe
else
{
- // extensions manager window NOT already open - open with 'subscribe' argument (this will show feeds pane, call doShowFeedPreview)
+ // extensions manager window NOT already open - open with 'subscribe' argument (this will show collection pane, call doShowCollectionPreview)
const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
@@ -173,22 +173,22 @@ Bandwagon.Controller.BrowserOverlay.showNewFeedItemsAlert = function(feed)
const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
- // the em is not open - open it, and select this feed
+ // the em is not open - open it, and select this collection
if (window)